@@ -15,6 +15,7 @@ import ray
 import ray.dashboard.modules.reporter.reporter_consts as reporter_consts
 from ray.dashboard import k8s_utils
 import ray.dashboard.utils as dashboard_utils
+import ray.experimental.internal_kv as internal_kv
 import ray._private.services
 import ray._private.utils
 from ray.core.generated import reporter_pb2
@@ -143,13 +144,15 @@ class ReporterAgent(dashboard_utils.DashboardAgentModule,
             self._cpu_counts = (psutil.cpu_count(),
                                 psutil.cpu_count(logical=False))
 
-        self._ip = ray.util.get_node_ip_address()
+        self._ip = dashboard_agent.ip
         self._redis_address, _ = dashboard_agent.redis_address
         self._is_head_node = (self._ip == self._redis_address)
         self._hostname = socket.gethostname()
         self._workers = set()
         self._network_stats_hist = [(0, (0.0, 0.0))]  # time, (sent, recv)
-        self._metrics_agent = MetricsAgent(dashboard_agent.metrics_export_port)
+        self._metrics_agent = MetricsAgent(
+            "127.0.0.1" if self._ip == "127.0.0.1" else "",
+            dashboard_agent.metrics_export_port)
         self._key = f"{reporter_consts.REPORTER_PREFIX}" \
                     f"{self._dashboard_agent.node_id}"
 
@@ -528,8 +531,8 @@ class ReporterAgent(dashboard_utils.DashboardAgentModule,
         """Get any changes to the log files and push updates to Redis."""
         while True:
             try:
-                formatted_status_string = await aioredis_client.hget(
-                    DEBUG_AUTOSCALING_STATUS, "value")
+                formatted_status_string = internal_kv._internal_kv_get(
+                    DEBUG_AUTOSCALING_STATUS)
                 formatted_status = json.loads(formatted_status_string.decode(
                 )) if formatted_status_string else {}
 
