@@ -1,4 +1,4 @@
-from ray.rllib.evaluation.episode import MultiAgentEpisode
+from ray.rllib.evaluation.episode import Episode, MultiAgentEpisode
 from ray.rllib.evaluation.rollout_worker import RolloutWorker
 from ray.rllib.evaluation.sample_batch_builder import (
     SampleBatchBuilder, MultiAgentSampleBatchBuilder)
@@ -17,5 +17,6 @@ __all__ = [
     "AsyncSampler",
     "compute_advantages",
     "collect_metrics",
-    "MultiAgentEpisode",
+    "Episode",
+    "MultiAgentEpisode",  # Deprecated -> Use `Episode` instead.
 ]
